<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Cài đặt nhóm</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Tên nhóm:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>ID nhóm:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Những người dùng trong nhóm này:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Lỗi</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Tên nhóm không được phép để trống.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Cài đặt nhóm và người dùng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Người dùng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Tên đăng nhập</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>ID người dùng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Tên đầy đủ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Nhóm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Thư mục home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Hiện thị người dùng hệ thống (chỉ dành cho người chuyên sâu)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Nhóm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>ID nhóm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Thành viên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Edit properties of the selected item</source>
        <translation>Chỉnh sửa thuộc tính của mục đã chọn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Thêm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Thêm nhóm hoặc người dùng mới</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Xóa mục đã chọn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Thuộc tính</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Làm mới</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Làm mới danh sách</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Thay đổi mật khẩu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Thay đổi mật khẩu cho nhóm hoặc người dùng đã chọn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Bạn có chắc muốn xóa người dùng đã chọn?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Bạn có chắc muốn xóa nhóm đã chọn?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="202"/>
        <source>Input the new password for %1:</source>
        <translation>Nhập mật khẩu mới cho %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Bạn có chắc là muốn để trống mật khẩu?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Cài đặt người dùng</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Chung</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Tên đầy đủ:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Tên đăng nhập:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID người dùng:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Nhóm chính:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Nhóm</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>Người dùng thuộc về những nhóm sau:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Nâng cao</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Shell đăng nhập:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Thư mục home:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Lỗi</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>Tên người dùng không được phép để trống.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="229"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Hành động (%1) thất bại:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
